@@ -1,6 +1,8 @@
 # coding=utf-8
 
 from .util import send_mail_util
+from .util import json_util
+
 
 class Tool(object):
     def __init__(self):
@@ -10,3 +12,11 @@ class Tool(object):
 
     def send_mail_msg(self, to_user, subject, content):
         send_mail_util(self.mail_from_user, self.mail_from_user_pwd, self.mail_from_host, to_user, subject, content)
+
+    @staticmethod
+    def json_loads(json_str):
+        return json_util(json_str, 'json_load', indent=None)
+
+    @staticmethod
+    def json_dumps(dict_str, **kwargs):
+        return json_util(dict_str, 'json_dump', **kwargs)
