@@ -1,8 +1,9 @@
 # coding=utf-8
 
-
+import json
 import yagmail
 
+
 def send_mail_util(from_user, pwd, host, to_user, subject, content):
     """
     发送邮件
@@ -16,3 +17,11 @@ def send_mail_util(from_user, pwd, host, to_user, subject, content):
     """
     with yagmail.SMTP(user=from_user, password=pwd, host=host) as yag:
         yag.send(to_user, subject, content)
+
+
+def json_util(pre_json, to_json_type, **kwargs):
+    try:
+        return json.loads(pre_json) if to_json_type == 'json_load' else json.dumps(
+            pre_json, ensure_ascii=False, **kwargs)
+    except:
+        return pre_json
